@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2014 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -12,14 +12,14 @@
  *   GNU General Public License for more details.                          *
  *                                                                         *
  *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, see <http://www.gnu.org/licenses/>.  *
+ *   along with this program; if not, see <https://www.gnu.org/licenses/>. *
  ***************************************************************************/
 
 #include "preamble.h"
 
 #include <typeinfo>
 
-#include <QRegExp>
+#include <QDebug>
 #include <QStringList>
 
 /**
@@ -49,6 +49,16 @@ Preamble::~Preamble()
     delete d;
 }
 
+bool Preamble::operator==(const Preamble &other) const
+{
+    return d->value == other.d->value;
+}
+
+bool Preamble::operator!=(const Preamble &other) const
+{
+    return !operator ==(other);
+}
+
 Preamble &Preamble::operator= (const Preamble &other)
 {
     if (this != &other)
@@ -75,3 +85,8 @@ void Preamble::setValue(const Value &value)
 bool Preamble::isPreamble(const Element &other) {
     return typeid(other) == typeid(Preamble);
 }
+
+QDebug operator<<(QDebug dbg, const Preamble &preamble) {
+    dbg.nospace() << "Preamble: " << preamble.value();
+    return dbg;
+}
