@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2014 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2020 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -12,8 +12,9 @@
  *   GNU General Public License for more details.                          *
  *                                                                         *
  *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, see <http://www.gnu.org/licenses/>.  *
+ *   along with this program; if not, see <https://www.gnu.org/licenses/>. *
  ***************************************************************************/
+
 #ifndef KBIBTEX_GUI_MENULINEEDIT_H
 #define KBIBTEX_GUI_MENULINEEDIT_H
 
@@ -22,7 +23,7 @@
 #include <QFrame>
 
 class QMenu;
-class KIcon;
+class QIcon;
 
 /**
 @author Thomas Fischer
@@ -46,13 +47,13 @@ public:
     static const QString keyLimitKeyboardTabStops;
 
     MenuLineEdit(bool isMultiLine, QWidget *parent);
-    ~MenuLineEdit();
+    ~MenuLineEdit() override;
 
     void setMenu(QMenu *menu);
     virtual void setReadOnly(bool);
     QString text() const;
     void setText(const QString &);
-    void setIcon(const KIcon &icon);
+    void setIcon(const QIcon &icon);
     void setFont(const QFont &font);
     void setButtonToolTip(const QString &);
     void setChildAcceptDrops(bool acceptDrops);
@@ -62,14 +63,16 @@ public:
     void appendWidget(QWidget *widget);
     void setInnerWidgetsTransparency(bool makeInnerWidgetsTransparent);
 
+    virtual void clear();
     bool isModified() const;
     void setCompletionItems(const QStringList &items);
 
 protected:
-    virtual void focusInEvent(QFocusEvent *event);
+    void focusInEvent(QFocusEvent *event) override;
 
 signals:
     void textChanged(const QString &);
+    void modified();
 
 private slots:
     void slotTextChanged();
