@@ -53,7 +53,6 @@ void FileExporterPS::reloadConfig()
 
     KConfigGroup configGroupGeneral(config, QStringLiteral("General"));
     m_paperSize = configGroupGeneral.readEntry(keyPaperSize, defaultPaperSize);
-    m_font = configGroupGeneral.readEntry(keyFont, defaultFont);
 }
 
 bool FileExporterPS::save(QIODevice *iodevice, const File *bibtexfile, QStringList *errorLog)
@@ -130,8 +129,6 @@ bool FileExporterPS::writeLatexFile(const QString &filename)
             ts << "\\usepackage{html}" << endl << "\\usepackage[dcucite]{harvard}" << endl << "\\renewcommand{\\harvardurl}{URL: \\url}" << endl;
         if (kpsewhich(QStringLiteral("geometry.sty")))
             ts << "\\usepackage[paper=" << m_paperSize << (m_paperSize.length() <= 2 ? "paper" : "") << "]{geometry}" << endl;
-        if (!m_font.isEmpty() && kpsewhich(m_font + QStringLiteral(".sty")))
-            ts << "\\usepackage{" << m_font << "}" << endl;
         ts << "\\bibliographystyle{" << m_bibliographyStyle << "}" << endl;
         ts << "\\begin{document}" << endl;
         ts << "\\nocite{*}" << endl;
