@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2017 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -22,9 +22,13 @@
 #include <QNetworkAccessManager>
 #include <QNetworkReply>
 #include <QUrlQuery>
+#include <QRegularExpression>
+#include <QRegularExpressionMatchIterator>
 
 #ifdef HAVE_KF5
 #include <KLocalizedString>
+#else // HAVE_KF5
+#define i18n(text) QObject::tr(text)
 #endif // HAVE_KF5
 
 #include "file.h"
@@ -35,9 +39,6 @@
 
 class OnlineSearchAcmPortal::OnlineSearchAcmPortalPrivate
 {
-private:
-    // UNUSED OnlineSearchAcmPortal *p;
-
 public:
     QString joinedQueryString;
     int numExpectedResults, numFoundResults;
@@ -45,25 +46,25 @@ public:
     int currentSearchPosition;
     QStringList citationUrls;
 
-    OnlineSearchAcmPortalPrivate(OnlineSearchAcmPortal */* UNUSED parent*/)
-        : /* UNUSED p(parent),*/ numExpectedResults(0), numFoundResults(0),
+    OnlineSearchAcmPortalPrivate(OnlineSearchAcmPortal *)
+            : numExpectedResults(0), numFoundResults(0),
           acmPortalBaseUrl(QStringLiteral("https://dl.acm.org/")), currentSearchPosition(0) {
-        // nothing
+        /// nothing
     }
 
     void sanitizeBibTeXCode(QString &code) {
-        const QRegExp htmlEncodedChar("&#(\\d+);");
-        while (htmlEncodedChar.indexIn(code) >= 0) {
+        static const QRegularExpression htmlEncodedChar(QStringLiteral("&#(\\d+);"));
+        QRegularExpressionMatch match;
+        while ((match = htmlEncodedChar.match(code)).hasMatch()) {
             bool ok = false;
-            QChar c(htmlEncodedChar.cap(1).toInt(&ok));
-            if (ok) {
-                code = code.replace(htmlEncodedChar.cap(0), c);
-            }
+            QChar c(match.captured(1).toInt(&ok));
+            if (ok)
+                code = code.replace(match.captured(0), c);
         }
 
         /// ACM's BibTeX code does not properly use various commands.
         /// For example, ACM writes "Ke\ssler" instead of "Ke{\ss}ler"
-        static const QStringList inlineCommands = QStringList() << QStringLiteral("\\ss");
+        static const QStringList inlineCommands {QStringLiteral("\\ss")};
         for (const QString &cmd : inlineCommands) {
             const QString wrappedCmd = QString(QStringLiteral("{%1}")).arg(cmd);
             code = code.replace(cmd, wrappedCmd);
@@ -74,7 +75,7 @@ public:
 OnlineSearchAcmPortal::OnlineSearchAcmPortal(QObject *parent)
         : OnlineSearchAbstract(parent), d(new OnlineSearchAcmPortalPrivate(this))
 {
-    // nothing
+    /// nothing
 }
 
 OnlineSearchAcmPortal::~OnlineSearchAcmPortal()
@@ -101,6 +102,8 @@ void OnlineSearchAcmPortal::startSearch(const QMap<QString, QString> &query, int
     QNetworkReply *reply = InternalNetworkAccessManager::instance().get(request);
     InternalNetworkAccessManager::instance().setNetworkReplyTimeout(reply);
     connect(reply, &QNetworkReply::finished, this, &OnlineSearchAcmPortal::doneFetchingStartPage);
+
+    refreshBusyProperty();
 }
 
 QString OnlineSearchAcmPortal::label() const
@@ -142,8 +145,9 @@ void OnlineSearchAcmPortal::doneFetchingStartPage()
             qCWarning(LOG_KBIBTEX_NETWORKING) << "Search using" << label() << "failed.";
             stopSearch(resultUnspecifiedError);
         }
-    } else
-        qCWarning(LOG_KBIBTEX_NETWORKING) << "url was" << reply->url().toDisplayString();
+    }
+
+    refreshBusyProperty();
 }
 
 void OnlineSearchAcmPortal::doneFetchingSearchPage()
@@ -155,10 +159,11 @@ void OnlineSearchAcmPortal::doneFetchingSearchPage()
     if (handleErrors(reply)) {
         const QString htmlSource = QString::fromUtf8(reply->readAll().constData());
 
-        static const QRegExp citationUrlRegExp(QStringLiteral("citation.cfm\\?id=[0-9][0-9.]+[0-9]"), Qt::CaseInsensitive);
-        int p1 = -1;
-        while ((p1 = citationUrlRegExp.indexIn(htmlSource, p1 + 1)) >= 0) {
-            const QString newUrl = d->acmPortalBaseUrl + citationUrlRegExp.cap(0);
+        static const QRegularExpression citationUrlRegExp(QStringLiteral("citation.cfm\\?id=[0-9][0-9.]+[0-9]"), QRegularExpression::CaseInsensitiveOption);
+        QRegularExpressionMatchIterator citationUrlRegExpMatchIt = citationUrlRegExp.globalMatch(htmlSource);
+        while (citationUrlRegExpMatchIt.hasNext()) {
+            const QRegularExpressionMatch citationUrlRegExpMatch = citationUrlRegExpMatchIt.next();
+            const QString newUrl = d->acmPortalBaseUrl + citationUrlRegExpMatch.captured(0);
             d->citationUrls << newUrl;
         }
 
@@ -179,12 +184,11 @@ void OnlineSearchAcmPortal::doneFetchingSearchPage()
             InternalNetworkAccessManager::instance().setNetworkReplyTimeout(newReply);
             connect(newReply, &QNetworkReply::finished, this, &OnlineSearchAcmPortal::doneFetchingCitation);
             d->citationUrls.removeFirst();
-        } else {
+        } else
             stopSearch(resultNoError);
-            emit progress(curStep = numSteps, numSteps);
-        }
-    } else
-        qCWarning(LOG_KBIBTEX_NETWORKING) << "url was" << reply->url().toDisplayString();
+    }
+
+    refreshBusyProperty();
 }
 
 void OnlineSearchAcmPortal::doneFetchingCitation()
@@ -197,20 +201,25 @@ void OnlineSearchAcmPortal::doneFetchingCitation()
     if (handleErrors(reply)) {
         const QString htmlSource = QString::fromUtf8(reply->readAll().constData());
 
-        static const QRegExp idRegExp(QStringLiteral("citation_abstract_html_url\" content=\"http://dl.acm.org/citation.cfm\\?id=([0-9]+)[.]([0-9]+)"));
-        int p = -1;
-        while ((p = idRegExp.indexIn(htmlSource, p + 1)) > 0) {
-            const QString parentId = idRegExp.cap(1);
-            const QString id = idRegExp.cap(2);
+        static const QRegularExpression idRegExp(QStringLiteral("citation_abstract_html_url\" content=\"http://dl.acm.org/citation.cfm\\?id=([0-9]+)[.]([0-9]+)"));
+        QRegularExpressionMatchIterator idRegExpMatchIt = idRegExp.globalMatch(htmlSource);
+        while (idRegExpMatchIt.hasNext()) {
+            const QRegularExpressionMatch idRegExpMatch = idRegExpMatchIt.next();
+            const QString parentId = idRegExpMatch.captured(1);
+            const QString id = idRegExpMatch.captured(2);
             if (!parentId.isEmpty() && !id.isEmpty()) {
                 const QUrl bibTeXUrl(d->acmPortalBaseUrl + QString(QStringLiteral("/downformats.cfm?id=%1&parent_id=%2&expformat=bibtex")).arg(id, parentId));
                 bibTeXUrls.insert(bibTeXUrl);
+            } else {
+                qCWarning(LOG_KBIBTEX_NETWORKING) << "No citation link found in " << reply->url().toDisplayString() << "  parentId=" << parentId;
+                stopSearch(resultNoError);
+                emit progress(curStep = numSteps, numSteps);
+                return;
             }
         }
         if (bibTeXUrls.isEmpty())
-            qCWarning(LOG_KBIBTEX_NETWORKING) << "No citation link found in " << reply->url().toDisplayString();
-    } else
-        qCWarning(LOG_KBIBTEX_NETWORKING) << "url was" << reply->url().toDisplayString();
+            qCWarning(LOG_KBIBTEX_NETWORKING) << "No citation link found in " << InternalNetworkAccessManager::removeApiKey(reply->url()).toDisplayString();
+    }
 
     if (bibTeXUrls.isEmpty()) {
         if (!d->citationUrls.isEmpty()) {
@@ -219,10 +228,8 @@ void OnlineSearchAcmPortal::doneFetchingCitation()
             InternalNetworkAccessManager::instance().setNetworkReplyTimeout(newReply);
             connect(newReply, &QNetworkReply::finished, this, &OnlineSearchAcmPortal::doneFetchingCitation);
             d->citationUrls.removeFirst();
-        } else {
+        } else
             stopSearch(resultNoError);
-            emit progress(curStep = numSteps, numSteps);
-        }
     } else {
         numSteps += bibTeXUrls.count() - 1;
         for (QSet<const QUrl>::ConstIterator it = bibTeXUrls.constBegin(); it != bibTeXUrls.constEnd(); ++it) {
@@ -233,6 +240,8 @@ void OnlineSearchAcmPortal::doneFetchingCitation()
             connect(newReply, &QNetworkReply::finished, this, &OnlineSearchAcmPortal::doneFetchingBibTeX);
         }
     }
+
+    refreshBusyProperty();
 }
 
 void OnlineSearchAcmPortal::doneFetchingBibTeX()
@@ -264,10 +273,9 @@ void OnlineSearchAcmPortal::doneFetchingBibTeX()
             InternalNetworkAccessManager::instance().setNetworkReplyTimeout(newReply);
             connect(newReply, &QNetworkReply::finished, this, &OnlineSearchAcmPortal::doneFetchingCitation);
             d->citationUrls.removeFirst();
-        } else {
+        } else
             stopSearch(resultNoError);
-            emit progress(curStep = numSteps, numSteps);
-        }
-    } else
-        qCWarning(LOG_KBIBTEX_NETWORKING) << "url was" << reply->url().toDisplayString();
+    }
+
+    refreshBusyProperty();
 }
