@@ -632,7 +632,8 @@ public:
                 msg += i18n("The following output was generated by the export filter:");
                 KMessageBox::errorList(p->widget(), msg, errorLog, i18n("Saving bibliography failed"));
             }
-        }
+        } else
+            bibTeXFile->setProperty(File::Url, url);
         return result;
     }
 
@@ -852,10 +853,9 @@ bool KBibTeXPart::documentSaveAs()
         qCWarning(LOG_KBIBTEX_PARTS) << "Not removing" << url().url(QUrl::PreferLocalFile) << "from fileSystemWatcher";
 
     // TODO how does SaveAs dialog know which mime types to support?
-    if (KParts::ReadWritePart::saveAs(newUrl)) {
-        // FIXME d->model->bibliographyFile()->setProperty(File::Url, newUrl);
+    if (KParts::ReadWritePart::saveAs(newUrl))
         return true;
-    } else
+    else
         return false;
 }
 
@@ -879,7 +879,9 @@ void KBibTeXPart::elementViewDocument()
     /// Go through all actions (i.e. document URLs) for this element
     for (const QAction *action : actionList) {
         /// Make URL from action's data ...
-        QUrl tmpUrl = QUrl(action->data().toString());
+        const QString actionData = action->data().toString();
+        if (actionData.isEmpty()) continue; ///< No URL from empty string
+        const QUrl tmpUrl = QUrl::fromUserInput(actionData);
         /// ... but skip this action if the URL is invalid
         if (!tmpUrl.isValid()) continue;
         if (tmpUrl.isLocalFile()) {
