@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2014 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -12,44 +12,39 @@
  *   GNU General Public License for more details.                          *
  *                                                                         *
  *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, see <http://www.gnu.org/licenses/>.  *
+ *   along with this program; if not, see <https://www.gnu.org/licenses/>. *
  ***************************************************************************/
 
 #include "lyx.h"
 
 #include <QWidget>
+#include <QAction>
 #include <QDir>
 #include <QTextStream>
 #include <QFileInfo>
+#include <QStandardPaths>
+#include <qplatformdefs.h>
 
-#include <KAction>
 #include <KActionCollection>
-#include <KLocale>
+#include <KLocalizedString>
 #include <KParts/ReadOnlyPart>
 #include <KMessageBox>
-#include <KStandardDirs>
-#include <KDebug>
 #include <KSharedConfig>
 #include <KConfigGroup>
-#include <kde_file.h>
-
-#include <kdeversion.h>
 
 class LyX::LyXPrivate
 {
-private:
-    // UNUSED LyX *p;
-
 public:
     QWidget *widget;
-    KAction *action;
+    QAction *action;
     QStringList references;
 
     KSharedConfigPtr config;
     const KConfigGroup group;
 
-    LyXPrivate(LyX */* UNUSED parent*/, QWidget *widget)
-        : /* UNUSED p(parent),*/ action(NULL), config(KSharedConfig::openConfig(QLatin1String("kbibtexrc"))), group(config, LyX::configGroupName) {
+    LyXPrivate(LyX *parent, QWidget *widget)
+            : action(nullptr), config(KSharedConfig::openConfig(QStringLiteral("kbibtexrc"))), group(config, LyX::configGroupName) {
+        Q_UNUSED(parent)
         this->widget = widget;
     }
 
@@ -61,12 +56,14 @@ public:
         if (!group.readEntry(keyUseAutomaticLyXPipeDetection, defaultUseAutomaticLyXPipeDetection))
             result = group.readEntry(keyLyXPipePath, defaultLyXPipePath);
 
+#ifdef QT_LSTAT
         /// Check if the result so far is empty. This means that
         /// either automatic detection is enabled or the path in
         /// the configuration is empty/invalid. Proceed with
         /// automatic detection in this case.
         if (result.isEmpty())
             result = LyX::guessLyXPipeLocation();
+#endif // QT_LSTAT
 
         /// Finally, even if automatic detection was preferred by the user,
         /// still check configuration for a path if automatic detection failed
@@ -78,25 +75,20 @@ public:
     }
 };
 
-const QString LyX::keyUseAutomaticLyXPipeDetection = QLatin1String("UseAutomaticLyXPipeDetection");
-const QString LyX::keyLyXPipePath = QLatin1String("LyXPipePath");
-const bool LyX::defaultUseAutomaticLyXPipeDetection =
-#ifdef Q_WS_WIN
-    false; /// Windows is not supported yet
-#else // Q_WS_WIN
-    true;
-#endif // Q_WS_WIN
+const QString LyX::keyUseAutomaticLyXPipeDetection = QStringLiteral("UseAutomaticLyXPipeDetection");
+const QString LyX::keyLyXPipePath = QStringLiteral("LyXPipePath");
+const bool LyX::defaultUseAutomaticLyXPipeDetection = true;
 const QString LyX::defaultLyXPipePath = QString();
-const QString LyX::configGroupName = QLatin1String("LyXPipe");
+const QString LyX::configGroupName = QStringLiteral("LyXPipe");
 
 
 LyX::LyX(KParts::ReadOnlyPart *part, QWidget *widget)
         : QObject(part), d(new LyX::LyXPrivate(this, widget))
 {
-    d->action = new KAction(KIcon("application-x-lyx"), i18n("Send to LyX/Kile"), this);
-    part->actionCollection()->addAction("sendtolyx", d->action);
+    d->action = new QAction(QIcon::fromTheme(QStringLiteral("application-x-lyx")), i18n("Send to LyX/Kile"), this);
+    part->actionCollection()->addAction(QStringLiteral("sendtolyx"), d->action);
     d->action->setEnabled(false);
-    connect(d->action, SIGNAL(triggered()), this, SLOT(sendReferenceToLyX()));
+    connect(d->action, &QAction::triggered, this, &LyX::sendReferenceToLyX);
     widget->addAction(d->action);
 }
 
@@ -108,7 +100,7 @@ LyX::~LyX()
 void LyX::setReferences(const QStringList &references)
 {
     d->references = references;
-    d->action->setEnabled(d->widget != NULL && !d->references.isEmpty());
+    d->action->setEnabled(d->widget != nullptr && !d->references.isEmpty());
 }
 
 void LyX::sendReferenceToLyX()
@@ -129,13 +121,13 @@ void LyX::sendReferenceToLyX()
     }
 
     QFile pipe(pipeName);
-    if (!QFileInfo(pipeName).exists() || !pipe.open(QFile::WriteOnly)) {
+    if (!QFileInfo::exists(pipeName) || !pipe.open(QFile::WriteOnly)) {
         KMessageBox::error(d->widget, i18n("Could not open LyX server pipe '%1'.", pipeName) + defaultHintOnLyXProblems, msgBoxTitle);
         return;
     }
 
     QTextStream ts(&pipe);
-    QString msg = QString(QLatin1String("LYXCMD:kbibtex:citation-insert:%1")).arg(d->references.join(","));
+    QString msg = QString(QStringLiteral("LYXCMD:kbibtex:citation-insert:%1")).arg(d->references.join(QStringLiteral(",")));
 
     ts << msg << endl;
     ts.flush();
@@ -143,38 +135,21 @@ void LyX::sendReferenceToLyX()
     pipe.close();
 }
 
+#ifdef QT_LSTAT
 QString LyX::guessLyXPipeLocation()
 {
-    KDE_struct_stat fileInfo;
-    const QStringList nameFilter = QStringList() << QLatin1String("*lyxpipe*in*");
-    QString result;
-
-    /// Start with scanning the user's home directory for pipes
-    QDir home = QDir::home();
-    QStringList files = home.entryList(nameFilter, QDir::Hidden | QDir::System | QDir::Writable, QDir::Unsorted);
-    foreach (const QString &filename, files) {
-        QString const absoluteFilename = home.absolutePath() + QDir::separator() + filename;
-        if (KDE_stat(absoluteFilename.toLatin1(), &fileInfo) == 0 && S_ISFIFO(fileInfo.st_mode)) {
-            result = absoluteFilename;
-            break;
+    QT_STATBUF statBuffer;
+    const QStringList nameFilter {QStringLiteral("*lyxpipe*in*")};
+    const QVector<QDir> directoriesToScan {QDir::home(), QDir(QDir::homePath() + QStringLiteral("/.lyx")), QDir::temp()};
+    for (const QDir &directory : directoriesToScan) {
+        const QStringList files = directory.entryList(nameFilter, QDir::Hidden | QDir::System | QDir::Writable, QDir::Unsorted);
+        for (const QString &filename : files) {
+            const QString canonicalFilename = QFileInfo(directory.absolutePath() + QDir::separator() + filename).canonicalFilePath();
+            if (QT_LSTAT(canonicalFilename.toLatin1(), &statBuffer) == 0 && S_ISFIFO(statBuffer.st_mode))
+                return canonicalFilename;
         }
     }
 
-    /// No hit yet? Search LyX's configuration directory
-    if (result.isEmpty()) {
-        QDir home = QDir::home();
-        if (home.cd(QLatin1String(".lyx"))) {
-            /// Same search again here
-            QStringList files = home.entryList(nameFilter, QDir::Hidden | QDir::System | QDir::Writable, QDir::Unsorted);
-            foreach (const QString &filename, files) {
-                QString const absoluteFilename = home.absolutePath() + QDir::separator() + filename;
-                if (KDE_stat(absoluteFilename.toLatin1(), &fileInfo) == 0 && S_ISFIFO(fileInfo.st_mode)) {
-                    result = absoluteFilename;
-                    break;
-                }
-            }
-        }
-    }
-
-    return result;
+    return QString();
 }
+#endif // QT_LSTAT
