@@ -419,22 +419,35 @@ public:
         return left->lastAccess() > right->lastAccess(); /// reverse sorting!
     }
 
-    void readConfig() {
+    void readConfig(QUrl &recentlyOpenURL) {
         readConfig(OpenFileInfo::RecentlyUsed, configGroupNameRecentlyUsed, maxNumRecentlyUsedFiles);
         readConfig(OpenFileInfo::Favorite, configGroupNameFavorites, maxNumFavoriteFiles);
         readConfig(OpenFileInfo::Open, configGroupNameOpen, maxNumOpenFiles);
+
+        KSharedConfigPtr config = KSharedConfig::openConfig(QStringLiteral("kbibtexrc"));
+        KConfigGroup cg(config, configGroupNameOpen);
+        static const QString recentlyOpenURLkey = OpenFileInfo::OpenFileInfoPrivate::keyURL + QStringLiteral("-current");
+        recentlyOpenURL = cg.hasKey(recentlyOpenURLkey) ? QUrl(cg.readEntry(recentlyOpenURLkey)) : QUrl();
     }
 
     void writeConfig() {
         writeConfig(OpenFileInfo::RecentlyUsed, configGroupNameRecentlyUsed, maxNumRecentlyUsedFiles);
         writeConfig(OpenFileInfo::Favorite, configGroupNameFavorites, maxNumFavoriteFiles);
         writeConfig(OpenFileInfo::Open, configGroupNameOpen, maxNumOpenFiles);
+
+        KSharedConfigPtr config = KSharedConfig::openConfig(QStringLiteral("kbibtexrc"));
+        KConfigGroup cg(config, configGroupNameOpen);
+        static const QString recentlyOpenURLkey = OpenFileInfo::OpenFileInfoPrivate::keyURL + QStringLiteral("-current");
+        if (currentFileInfo != nullptr && currentFileInfo->url().isValid())
+            /// If there is a currently active and open file, remember that file's URL
+            cg.writeEntry(recentlyOpenURLkey, currentFileInfo->url().url(QUrl::PreferLocalFile));
+        else
+            cg.deleteEntry(recentlyOpenURLkey);
     }
 
     void readConfig(OpenFileInfo::StatusFlag statusFlag, const QString &configGroupName, int maxNumFiles) {
         KSharedConfigPtr config = KSharedConfig::openConfig(QStringLiteral("kbibtexrc"));
 
-        bool isFirst = true;
         KConfigGroup cg(config, configGroupName);
         for (int i = 0; i < maxNumFiles; ++i) {
             QUrl fileUrl = QUrl(cg.readEntry(QString(QStringLiteral("%1-%2")).arg(OpenFileInfo::OpenFileInfoPrivate::keyURL).arg(i), ""));
@@ -455,11 +468,6 @@ public:
             ofi->addFlags(statusFlag);
             ofi->addFlags(OpenFileInfo::HasName);
             ofi->setLastAccess(QDateTime::fromString(cg.readEntry(QString(QStringLiteral("%1-%2")).arg(OpenFileInfo::OpenFileInfoPrivate::keyLastAccess).arg(i), ""), OpenFileInfo::OpenFileInfoPrivate::dateTimeFormat));
-            if (isFirst) {
-                isFirst = false;
-                if (statusFlag == OpenFileInfo::Open)
-                    p->setCurrentFile(ofi);
-            }
         }
     }
 
@@ -493,7 +501,28 @@ const int OpenFileInfoManager::OpenFileInfoManagerPrivate::maxNumOpenFiles = 16;
 OpenFileInfoManager::OpenFileInfoManager(QObject *parent)
         : QObject(parent), d(new OpenFileInfoManagerPrivate(this))
 {
-    QTimer::singleShot(300, this, &OpenFileInfoManager::delayedReadConfig);
+    QUrl recentlyOpenURL;
+    d->readConfig(recentlyOpenURL);
+
+    QTimer::singleShot(250, this, [this, recentlyOpenURL]() {
+        /// In case there is at least one file marked as 'open' but it is not yet actually open,
+        /// set it as current file now. The file to be opened (identified by URL) should be
+        /// preferrably the file that was actively open at the end of last KBibTeX session.
+        /// Slightly delaying the actually opening of files is necessary to give precendence
+        /// to bibliography files passed as command line arguments (see program.cpp) over files
+        /// that where open when the previous KBibTeX session was quit.
+        /// See KDE bug 417164.
+        /// TODO still necessary to refactor the whole 'file opening' control flow to avoid hacks like this one
+        if (d->currentFileInfo == nullptr) {
+            OpenFileInfo *ofiToUse = nullptr;
+            /// Go over the list of files that are flagged as 'open' ...
+            for (auto *ofi : const_cast<const OpenFileInfoManager::OpenFileInfoList &>(d->openFileInfoList))
+                if (ofi->flags().testFlag(OpenFileInfo::Open) && (ofiToUse == nullptr || (recentlyOpenURL.isValid() && ofi->url() == recentlyOpenURL)))
+                    ofiToUse = ofi;
+            if (ofiToUse != nullptr)
+                setCurrentFile(ofiToUse);
+        }
+    });
 }
 
 OpenFileInfoManager &OpenFileInfoManager::instance() {
@@ -710,8 +739,3 @@ void OpenFileInfoManager::deferredListsChanged()
     statusFlags |= OpenFileInfo::Favorite;
     emit flagsChanged(statusFlags);
 }
-
-void OpenFileInfoManager::delayedReadConfig()
-{
-    d->readConfig();
-}
